@@ -10,33 +10,35 @@ configure and implement a workflow to operate on a signac_ data space.
 """
 from __future__ import absolute_import
 from . import environment
-from . import scheduler
-from . import manage
+from . import scheduling
 from . import errors
 from .project import FlowProject
 from .project import JobOperation
 from .project import label
 from .project import classlabel
 from .project import staticlabel
-from .environment import get_environment
+from .operations import cmd
+from .operations import directives
 from .operations import run
-from .operations import redirect_log
+from .environment import get_environment
 from .template import init
+from .util.misc import redirect_log
 
-__version__ = '0.5.6'
+__version__ = '0.6.0'
 
 __all__ = [
     'environment',
-    'scheduler',
-    'manage',
+    'scheduling',
     'errors',
     'FlowProject',
     'JobOperation',
     'label',
     'classlabel',
     'staticlabel',
-    'get_environment',
+    'cmd',
+    'directives',
     'run',
-    'redirect_log',
     'init',
+    'redirect_log',
+    'get_environment',
     ]
